/*
 * Copyright 2019 by Kappich Systemberatung Aachen
 * ALL RIGHTS RESERVED.
 */

package de.bsvrz.dav.daf.accessControl.internal;

import java.util.concurrent.CopyOnWriteArrayList;

/**
 * Abstrakte Klasse, die die Listener-Funktionen der ObjectSelectionBlock-Klassen ("AuswahlBereich", "AuswahlRegion" usw.) kapselt
 *
 * @author Kappich Systemberatung
 * @version $Revision: 0000 $
 */
abstract class AbstractObjectSelectionBlock implements ObjectSelectionBlock {

	private final CopyOnWriteArrayList<ObjectCollectionChangeListener> _objectCollectionChangeListeners = new CopyOnWriteArrayList<>();

	/**
	 * Fügt einen neuen Listener hinzu, der über Änderungen an dieser Objektauswahl informiert wird
	 * @param object Listener Listener
	 */
	@Override
	public void addChangeListener(ObjectCollectionChangeListener object) {
		if(_objectCollectionChangeListeners.size() == 0) startChangeListener();
		_objectCollectionChangeListeners.add(object);
	}

	/**
	 * Entfernt einen Listener wieder
	 * @param object Listener Listener
	 */
	@Override
	public void removeChangeListener(ObjectCollectionChangeListener object) {
		_objectCollectionChangeListeners.remove(object);
		if(_objectCollectionChangeListeners.size() == 0) stopChangeListener();
	}

	@Override
	public void dispose() {
		_objectCollectionChangeListeners.clear();
		stopChangeListener();
	}

	/**
	 * Wird benutzt um Listener über Änderungen dieses Blocks zu informieren.
	 */
	protected void notifyBlockChanged() {
		for(final ObjectCollectionChangeListener objectCollectionChangeListener : _objectCollectionChangeListeners) {
			objectCollectionChangeListener.blockChanged();
		}
	}

	/** Startet, falls nötig, eventuelle interne Listener, die den Änderungsstatus der verwalteten Objekte überwachen */
	void startChangeListener() {
	}

	/** Stoppt die mit {@link #startChangeListener()} gestarteten Überwachungen */
	void stopChangeListener() {
	}
}
